@@ -76,7 +76,7 @@ pub enum AdminRequestCli {
     DisableApp(DisableApp),
     DumpState(DumpState),
     /// Calls AdminRequest::AddAgentInfo.
-    /// [Unimplemented].
+    /// _Unimplemented_.
     AddAgents,
     ListAgents(ListAgents),
 }
@@ -499,8 +499,6 @@ pub async fn install_app_bundle(
         uid,
     } = args;
 
-    let bundle = AppBundleSource::Path(path).resolve().await?;
-
     let agent_key = match agent_key {
         Some(agent) => agent,
         None => generate_agent_pub_key(cmd).await?,
@@ -509,7 +507,7 @@ pub async fn install_app_bundle(
     let payload = InstallAppBundlePayload {
         installed_app_id: app_id,
         agent_key,
-        source: AppBundleSource::Bundle(bundle),
+        source: AppBundleSource::Path(path),
         membrane_proofs: Default::default(),
         uid,
     };
